@@ -300,6 +300,60 @@ class IntegralMoment(Functional):
         return result
 
 
+class IntegralMomentOfNormalDerivative(Functional):
+    """Functional giving normal derivative integrated against some function on a facet."""
+
+    def __init__(self, ref_el, facet_no, Q, f_at_qpts):
+        n = ref_el.compute_normal(facet_no)
+        self.n = n
+        self.f_at_qpts = f_at_qpts
+        self.Q = Q
+
+        sd = ref_el.get_spatial_dimension()
+
+        # map points onto facet
+
+        fmap = ref_el.get_entity_transform(sd-1, facet_no)
+        qpts, qwts = Q.get_points(), Q.get_weights()
+        dpts = [fmap(pt) for pt in qpts]
+        self.dpts = dpts
+
+        dpt_dict = OrderedDict()
+
+        alphas = [[1 if j == i else 0 for j in range(sd)] for i in range(sd)]
+        for j, pt in enumerate(dpts):
+            dpt_dict[tuple(pt)] = [(qwts[j]*n[i], alphas[i], tuple()) for i in range(sd)]
+
+        Functional.__init__(self, ref_el, tuple(),
+                            {}, dpt_dict, "IntegralMomentOfNormalDerivative")
+
+    def to_riesz(self, poly_set):
+        es = poly_set.get_expansion_set()
+        ed = poly_set.get_embedded_degree()
+
+        result = numpy.zeros(es.get_num_members(ed))
+        sd = self.ref_el.get_spatial_dimension()
+
+        X = sympy.DeferredVector('x')
+        dX = numpy.asarray([X[i] for i in range(sd)])
+
+        # evaluate bfs symbolically
+        bfs = es.tabulate(ed, [dX])[:, 0]
+
+        n = self.n
+        qwts = self.Q.get_weights()
+
+        for i in range(len(result)):
+            thing = sympy.lambdify(
+                X, sum([sympy.diff(bfs[i], dxi)*ni
+                        for dxi, ni in zip(dX, n)]))
+
+            for j, pt in enumerate(self.deriv_dict.keys()):
+                result[i] += qwts[j] * self.f_at_qpts[j] * thing(pt)
+
+        return result
+
+
 class FrobeniusIntegralMoment(Functional):
 
     def __init__(self, ref_el, Q, f_at_qpts):
